@@ -1,8 +1,15 @@
 """
 Sends updates to a Telegram bot.
+
+Usage:
+>>> from tqdm.contrib.telegram import tqdm, trange
+>>> for i in trange(10, token='{token}', chat_id='{chat_id}'):
+...     ...
+
+![screenshot](
+https://raw.githubusercontent.com/tqdm/img/src/screenshot-telegram.gif)
 """
 from __future__ import absolute_import
-from copy import deepcopy
 from os import getenv
 
 from requests import Session
@@ -61,10 +68,10 @@ class tqdm_telegram(tqdm_auto):
     Standard `tqdm.auto.tqdm` but also sends updates to a Telegram Bot.
     May take a few seconds to create (`__init__`).
 
-    - create a bot https://core.telegram.org/bots#6-botfather
+    - create a bot <https://core.telegram.org/bots#6-botfather>
     - copy its `{token}`
     - add the bot to a chat and send it a message such as `/start`
-    - go to https://api.telegram.org/bot`{token}`/getUpdates to find out
+    - go to <https://api.telegram.org/bot`{token}`/getUpdates> to find out
       the `{chat_id}`
     - paste the `{token}` & `{chat_id}` below
 
@@ -83,7 +90,7 @@ class tqdm_telegram(tqdm_auto):
 
         See `tqdm.auto.tqdm.__init__` for other parameters.
         """
-        kwargs = deepcopy(kwargs)
+        kwargs = kwargs.copy()
         self.tgio = TelegramIO(
             kwargs.pop('token', getenv('TQDM_TELEGRAM_TOKEN')),
             kwargs.pop('chat_id', getenv('TQDM_TELEGRAM_CHAT_ID')))
@@ -92,33 +99,13 @@ class tqdm_telegram(tqdm_auto):
     def display(self, **kwargs):
         super(tqdm_telegram, self).display(**kwargs)
         fmt = self.format_dict
-        if 'bar_format' in fmt and fmt['bar_format']:
-            fmt['bar_format'] = fmt['bar_format'].replace('<bar/>', '{bar}')
+        if fmt.get('bar_format', None):
+            fmt['bar_format'] = fmt['bar_format'].replace(
+                '<bar/>', '{bar:10u}').replace('{bar}', '{bar:10u}')
         else:
-            fmt['bar_format'] = '{l_bar}{bar}{r_bar}'
-        fmt['bar_format'] = fmt['bar_format'].replace('{bar}', '{bar:10u}')
+            fmt['bar_format'] = '{l_bar}{bar:10u}{r_bar}'
         self.tgio.write(self.format_meter(**fmt))
 
-    def __new__(cls, *args, **kwargs):
-        """
-        Workaround for mixed-class same-stream nested progressbars.
-        See [#509](https://github.com/tqdm/tqdm/issues/509)
-        """
-        with cls.get_lock():
-            try:
-                cls._instances = tqdm_auto._instances
-            except AttributeError:
-                pass
-        instance = super(tqdm_telegram, cls).__new__(cls, *args, **kwargs)
-        with cls.get_lock():
-            try:
-                # `tqdm_auto` may have been changed so update
-                cls._instances.update(tqdm_auto._instances)
-            except AttributeError:
-                pass
-            tqdm_auto._instances = cls._instances
-        return instance
-
 
 def ttgrange(*args, **kwargs):
     """
